==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionCatalogHealthFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class SubscriptionCatalogHealthFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<A>{
  public SubscriptionCatalogHealthFluentImpl() {
  }
  public SubscriptionCatalogHealthFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth instance) {
    this.withCatalogSourceRef(instance.getCatalogSourceRef()); 
    this.withHealthy(instance.getHealthy()); 
    this.withLastUpdated(instance.getLastUpdated()); 
  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder catalogSourceRef;
  private java.lang.Boolean healthy;
  private java.lang.String lastUpdated;
  
  /**
   * This method has been deprecated, please use method buildCatalogSourceRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getCatalogSourceRef() {
    return this.catalogSourceRef!=null?this.catalogSourceRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildCatalogSourceRef() {
    return this.catalogSourceRef!=null?this.catalogSourceRef.build():null;
  }
  public A withCatalogSourceRef(io.fabric8.kubernetes.api.model.ObjectReference catalogSourceRef) {
    _visitables.get("catalogSourceRef").remove(this.catalogSourceRef);
    if (catalogSourceRef!=null){ this.catalogSourceRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(catalogSourceRef); _visitables.get("catalogSourceRef").add(this.catalogSourceRef);} return (A) this;
  }
  public java.lang.Boolean hasCatalogSourceRef() {
    return this.catalogSourceRef != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRef() {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluentImpl.CatalogSourceRefNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluentImpl.CatalogSourceRefNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editCatalogSourceRef() {
    return withNewCatalogSourceRefLike(getCatalogSourceRef());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRef() {
    return withNewCatalogSourceRefLike(getCatalogSourceRef() != null ? getCatalogSourceRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewCatalogSourceRefLike(getCatalogSourceRef() != null ? getCatalogSourceRef(): item);
  }
  public java.lang.Boolean getHealthy() {
    return this.healthy;
  }
  public A withHealthy(java.lang.Boolean healthy) {
    this.healthy=healthy; return (A) this;
  }
  public java.lang.Boolean hasHealthy() {
    return this.healthy != null;
  }
  public java.lang.String getLastUpdated() {
    return this.lastUpdated;
  }
  public A withLastUpdated(java.lang.String lastUpdated) {
    this.lastUpdated=lastUpdated; return (A) this;
  }
  public java.lang.Boolean hasLastUpdated() {
    return this.lastUpdated != null;
  }
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0) {
    return (A)withLastUpdated(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubscriptionCatalogHealthFluentImpl that = (SubscriptionCatalogHealthFluentImpl) o;
    if (catalogSourceRef != null ? !catalogSourceRef.equals(that.catalogSourceRef) :that.catalogSourceRef != null) return false;
    if (healthy != null ? !healthy.equals(that.healthy) :that.healthy != null) return false;
    if (lastUpdated != null ? !lastUpdated.equals(that.lastUpdated) :that.lastUpdated != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(catalogSourceRef,  healthy,  lastUpdated,  super.hashCode());
  }
  public class CatalogSourceRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CatalogSourceRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    CatalogSourceRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) SubscriptionCatalogHealthFluentImpl.this.withCatalogSourceRef(builder.build());
    }
    public N endCatalogSourceRef() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionCatalogHealthFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class SubscriptionCatalogHealthFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<A>{
  public SubscriptionCatalogHealthFluentImpl() {
  }
  public SubscriptionCatalogHealthFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealth instance) {
    this.withCatalogSourceRef(instance.getCatalogSourceRef()); 
    this.withHealthy(instance.getHealthy()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder catalogSourceRef;
  private java.lang.Boolean healthy;
  private java.lang.String lastUpdated;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCatalogSourceRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getCatalogSourceRef() {
    return this.catalogSourceRef!=null?this.catalogSourceRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildCatalogSourceRef() {
    return this.catalogSourceRef!=null?this.catalogSourceRef.build():null;
  }
  public A withCatalogSourceRef(io.fabric8.kubernetes.api.model.ObjectReference catalogSourceRef) {
    _visitables.get("catalogSourceRef").remove(this.catalogSourceRef);
    if (catalogSourceRef!=null){ this.catalogSourceRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(catalogSourceRef); _visitables.get("catalogSourceRef").add(this.catalogSourceRef);} return (A) this;
  }
  public java.lang.Boolean hasCatalogSourceRef() {
    return this.catalogSourceRef != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRef() {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluentImpl.CatalogSourceRefNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluentImpl.CatalogSourceRefNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editCatalogSourceRef() {
    return withNewCatalogSourceRefLike(getCatalogSourceRef());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRef() {
    return withNewCatalogSourceRefLike(getCatalogSourceRef() != null ? getCatalogSourceRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewCatalogSourceRefLike(getCatalogSourceRef() != null ? getCatalogSourceRef(): item);
  }
  public java.lang.Boolean getHealthy() {
    return this.healthy;
  }
  public A withHealthy(java.lang.Boolean healthy) {
    this.healthy=healthy; return (A) this;
  }
  public java.lang.Boolean hasHealthy() {
    return this.healthy != null;
  }
  public java.lang.String getLastUpdated() {
    return this.lastUpdated;
  }
  public A withLastUpdated(java.lang.String lastUpdated) {
    this.lastUpdated=lastUpdated; return (A) this;
  }
  public java.lang.Boolean hasLastUpdated() {
    return this.lastUpdated != null;
  }
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0) {
    return (A)withLastUpdated(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubscriptionCatalogHealthFluentImpl that = (SubscriptionCatalogHealthFluentImpl) o;
    if (catalogSourceRef != null ? !catalogSourceRef.equals(that.catalogSourceRef) :that.catalogSourceRef != null) return false;
    if (healthy != null ? !healthy.equals(that.healthy) :that.healthy != null) return false;
    if (lastUpdated != null ? !lastUpdated.equals(that.lastUpdated) :that.lastUpdated != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(catalogSourceRef,  healthy,  lastUpdated,  additionalProperties,  super.hashCode());
  }
  public class CatalogSourceRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CatalogSourceRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    CatalogSourceRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) SubscriptionCatalogHealthFluentImpl.this.withCatalogSourceRef(builder.build());
    }
    public N endCatalogSourceRef() {
      return and();
    }
    
  }
  
}
